Index: content/common/view_messages.h |
diff --git a/content/common/view_messages.h b/content/common/view_messages.h |
index 357c8ce5e22e9977c1cd0c2b78aa86ce2b666e19..aaf77b94c1181932964f6fa067a8b4cc9bcc1025 100644 |
--- a/content/common/view_messages.h |
+++ b/content/common/view_messages.h |
@@ -1043,8 +1043,8 @@ IPC_MESSAGE_ROUTED1(ViewMsg_DisableAutoResize, |
IPC_MESSAGE_ROUTED1(ViewMsg_SetTextDirection, |
blink::WebTextDirection /* direction */) |
-// Tells the renderer to clear the focused node (if any). |
-IPC_MESSAGE_ROUTED0(ViewMsg_ClearFocusedNode) |
+// Tells the renderer to clear the focused element (if any). |
+IPC_MESSAGE_ROUTED0(ViewMsg_ClearFocusedElement) |
// Make the RenderView transparent and render it onto a custom background. The |
// background will be tiled in both directions if it is not large enough. |